@@ -4,6 +4,7 @@
 namespace Icinga\Module\Monitoring\Forms\Command\Object;
 
 use DateTime;
+use Icinga\Application\Config;
 use Icinga\Module\Monitoring\Command\Object\PropagateHostDowntimeCommand;
 use Icinga\Module\Monitoring\Command\Object\ScheduleHostDowntimeCommand;
 use Icinga\Module\Monitoring\Command\Object\ScheduleServiceDowntimeCommand;
@@ -22,6 +23,8 @@ class ScheduleHostDowntimeCommandForm extends ScheduleServiceDowntimeCommandForm
     {
         parent::createElements($formData);
 
+        $config = Config::module('monitoring');
+
         $this->addElement(
             'checkbox',
             'all_services',
@@ -30,11 +33,13 @@ class ScheduleHostDowntimeCommandForm extends ScheduleServiceDowntimeCommandForm
                     'Schedule downtime for all services on the hosts and the hosts themselves.'
                 ),
                 'label'         => $this->translate('All Services'),
-                'value'         => false
+                'value'         => (bool) $config->get('settings', 'hostdowntime_all_services', false)
             )
         );
 
-        if (! $this->getBackend()->isIcinga2()) {
+        if (! $this->getBackend()->isIcinga2()
+            || version_compare($this->getBackend()->getProgramVersion(), '2.6.0', '>=')
+        ) {
             $this->addElement(
                 'select',
                 'child_hosts',
