@@ -17,6 +17,7 @@ use Icinga\Exception\ProgrammingError;
 use Icinga\Exception\QueryException;
 use Icinga\Web\Session;
 use Icinga\Module\Monitoring\Data\ColumnFilterIterator;
+use Zend_Db_Select;
 
 /**
  * Base class for Ido Queries
@@ -568,6 +569,13 @@ abstract class IdoQuery extends DbQuery
             $and = false;
         }
 
+        $alias = $filter->getColumn();
+        $column = $subQuery->aliasToColumnName($alias);
+        if (isset($this->caseInsensitiveColumns[$subQuery->aliasToTableName($alias)][$alias])) {
+            $column = 'LOWER( ' . $column . ' )';
+            $subQueryFilter->setExpression(array_map('strtolower', (array) $subQueryFilter->getExpression()));
+        }
+
         $additional = null;
 
         list($theirs, $ours) = $this->joinSubQuery($subQuery, $queryName, $subQueryFilter, $and, $negate, $additional);
@@ -620,7 +628,7 @@ abstract class IdoQuery extends DbQuery
         $subQueryFilter->setColumn(preg_replace(
             '/(?<=^|\s)\w+(?=\.)/',
             'sub_$0',
-            $subQuery->aliasToColumnName($filter->getColumn())
+            $column
         ));
 
         if ($negate) {
@@ -633,12 +641,6 @@ abstract class IdoQuery extends DbQuery
             new Zend_Db_Expr($ours)
         ));
 
-        if (! $negate) {
-            $subQueryFilter = $subQueryFilter->orFilter(
-                new FilterExpression($ours, '', new Zend_Db_Expr('IS NULL'))
-            );
-        }
-
         $subQuery
             ->setFilter($subQueryFilter)
             ->clearGroupingRules()
@@ -1188,7 +1190,13 @@ abstract class IdoQuery extends DbQuery
     {
         // TODO: This is not generic enough yet
         list($type, $name) = $this->customvarNameToTypeName($customvar);
-        $alias = ($type === 'host' ? 'hcv_' : 'scv_') . $name;
+        $alias = ($type === 'host' ? 'hcv_' : 'scv_') . preg_replace('~[^a-zA-Z0-9_]~', '_', $name);
+
+        // We're replacing any problematic char with an underscore, which will lead to duplicates, this avoids them
+        $from = $this->select->getPart(Zend_Db_Select::FROM);
+        for ($i = 2; array_key_exists($alias, $from); $i++) {
+            $alias = $alias . '_' . $i;
+        }
 
         $this->customVars[strtolower($customvar)] = $alias;
 
@@ -1227,7 +1235,7 @@ abstract class IdoQuery extends DbQuery
     protected function customvarNameToTypeName($customvar)
     {
         $customvar = strtolower($customvar);
-        if (! preg_match('~^_(host|service)_([a-zA-Z0-9_]+)$~', $customvar, $m)) {
+        if (! preg_match('~^_(host|service)_(.+)$~', $customvar, $m)) {
             throw new ProgrammingError(
                 'Got invalid custom var: "%s"',
                 $customvar
