@@ -214,6 +214,16 @@ class Perfdata
         return $this->value;
     }
 
+    /**
+     * Return the unit as a string
+     *
+     * @return string
+     */
+    public function getUnit()
+    {
+        return $this->unit;
+    }
+
     /**
      * Return the value as percentage (0-100)
      *
